Python library to Explore Emotions Behind Tweets
================================================

|license| |python_version| |coverage| |test|

python-sentiment is a Python package leveraging NLP algorithm and the Twitter API to score the sentiment of a tweet.

Installation 
------------ 
Installing twitter-sentiment is simple, you just have to use pip.
::

    pip install twitter-sentiment


Documentation
-------------  
Documentation is available at `twitter-sentiment.readthedocs.io <https://twitter-sentiment.readthedocs.io/en/latest/index.html>`_

twitter-sentiment in a nutshel  
------------------------------
twitter-sentiment let you score a tweet/list of tweets on a scale of -1 to 1. A score below 0 represents a negative tweet, while a score greater than 0 represents a positive tweet. To score a tweet, twitter-sentiment levereage TextBlob Naive Byaise NLP library. More information can be find at `textblob.readthedocs.io <https://textblob.readthedocs.io/en/dev/advanced_usage.html#sentiment-analyzers>`_

.. |license|  image:: https://img.shields.io/packagist/l/doctrine/orm.svg?style=flat-square   :alt: Packagist
.. |python_version| image:: https://img.shields.io/badge/Python-3-yellow.svg?style=flat-square
.. |test| image:: https://img.shields.io/teamcity/codebetter/bt428.svg?style=flat-square   :alt: TeamCity CodeBetter
.. |coverage| image:: https://img.shields.io/teamcity/coverage/bt428.svg?style=flat-square   :alt: TeamCity CodeBetter Coverage

